@@ -288,7 +288,8 @@ class IRInstruction:
         Check if instruction is pseudo, i.e. not an actual instruction but
         a construct for intermediate representation like phi and param.
         """
-        return self.is_phi or self.is_param
+        # do not reorder `source` instructions in dft pass - for testing
+        return self.is_phi or self.is_param or self.opcode == "source"
 
     def get_read_effects(self) -> effects.Effects:
         return effects.reads.get(self.opcode, effects.EMPTY)
